# Tricks & Stories

```{eval-rst}
.. toctree::
   :maxdepth: 1

   user-stories/overlaps.md
   user-stories/climatology.ipynb
   user-stories/climatology-hourly.ipynb
   user-stories/custom-aggregations.ipynb
```
